# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/constructs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/fitness_service/constructs.proto\x12\x14qwak.fitness.service\"\xa2\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x35\n\tmodel_uri\x18\x05 \x01(\x0b\x32\".qwak.fitness.service.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\"\x8d\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\"t\n\x08\x42uildEnv\x12\x33\n\ndocker_env\x18\x01 \x01(\x0b\x32\x1f.qwak.fitness.service.DockerEnv\x12\x33\n\npython_env\x18\x02 \x01(\x0b\x32\x1f.qwak.fitness.service.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"|\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\"j\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x03 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit\"\xaf\x01\n\x0cGpuResources\x12/\n\x08gpu_type\x18\x01 \x01(\x0e\x32\x1d.qwak.fitness.service.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x02\x12\x15\n\rmemory_amount\x18\x04 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x05 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x8c\x02\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c\x42#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
_GPUTYPE = DESCRIPTOR.enum_types_by_name['GpuType']
GpuType = enum_type_wrapper.EnumTypeWrapper(_GPUTYPE)
UNKNOWN_MEMORY_UNIT = 0
MIB = 1
GIB = 2
INVALID = 0
NVIDIA_K80 = 1
NVIDIA_V100 = 2
NVIDIA_A100 = 3
NVIDIA_T4 = 4
NVIDIA_A10G = 5
NVIDIA_L4 = 6
NVIDIA_T4_1_4_15 = 7
NVIDIA_T4_1_8_30 = 8
NVIDIA_T4_1_16_60 = 9
NVIDIA_A100_80GB_8_96_1360 = 10
NVIDIA_V100_1_8_52 = 11
NVIDIA_V100_4_32_208 = 12


_BUILDPROPERTIES = DESCRIPTOR.message_types_by_name['BuildProperties']
_MODELURISPEC = DESCRIPTOR.message_types_by_name['ModelUriSpec']
_BUILDENV = DESCRIPTOR.message_types_by_name['BuildEnv']
_DOCKERENV = DESCRIPTOR.message_types_by_name['DockerEnv']
_PYTHONENV = DESCRIPTOR.message_types_by_name['PythonEnv']
_CPURESOURCES = DESCRIPTOR.message_types_by_name['CpuResources']
_GPURESOURCES = DESCRIPTOR.message_types_by_name['GpuResources']
BuildProperties = _reflection.GeneratedProtocolMessageType('BuildProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildProperties)
  })
_sym_db.RegisterMessage(BuildProperties)

ModelUriSpec = _reflection.GeneratedProtocolMessageType('ModelUriSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELURISPEC,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.ModelUriSpec)
  })
_sym_db.RegisterMessage(ModelUriSpec)

BuildEnv = _reflection.GeneratedProtocolMessageType('BuildEnv', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildEnv)
  })
_sym_db.RegisterMessage(BuildEnv)

DockerEnv = _reflection.GeneratedProtocolMessageType('DockerEnv', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.DockerEnv)
  })
_sym_db.RegisterMessage(DockerEnv)

PythonEnv = _reflection.GeneratedProtocolMessageType('PythonEnv', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.PythonEnv)
  })
_sym_db.RegisterMessage(PythonEnv)

CpuResources = _reflection.GeneratedProtocolMessageType('CpuResources', (_message.Message,), {
  'DESCRIPTOR' : _CPURESOURCES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CpuResources)
  })
_sym_db.RegisterMessage(CpuResources)

GpuResources = _reflection.GeneratedProtocolMessageType('GpuResources', (_message.Message,), {
  'DESCRIPTOR' : _GPURESOURCES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.GpuResources)
  })
_sym_db.RegisterMessage(GpuResources)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _MEMORYUNIT._serialized_start=1043
  _MEMORYUNIT._serialized_end=1098
  _GPUTYPE._serialized_start=1101
  _GPUTYPE._serialized_end=1369
  _BUILDPROPERTIES._serialized_start=64
  _BUILDPROPERTIES._serialized_end=226
  _MODELURISPEC._serialized_start=229
  _MODELURISPEC._serialized_end=370
  _BUILDENV._serialized_start=372
  _BUILDENV._serialized_end=488
  _DOCKERENV._serialized_start=491
  _DOCKERENV._serialized_end=629
  _PYTHONENV._serialized_start=631
  _PYTHONENV._serialized_end=755
  _CPURESOURCES._serialized_start=757
  _CPURESOURCES._serialized_end=863
  _GPURESOURCES._serialized_start=866
  _GPURESOURCES._serialized_end=1041
# @@protoc_insertion_point(module_scope)
