# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/admiral/secret/v0/secret.proto\x12\x16qwak.admiral.secret.v0\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1f\n\x0eUserSecretSpec\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x10SystemSecretSpec\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.admiral.secret.v0.SystemSecretValue\"\x99\x01\n\x16SystemSecretDefinition\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpec\"C\n\x1b\x45nvironmentSecretIdentifier\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\xa0\x01\n\x1fSetUserEnvironmentSecretOptions\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32&.qwak.admiral.secret.v0.UserSecretSpec\"\xa4\x01\n!SetSystemEnvironmentSecretOptions\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpec\"\xa5\x01\n\x11SystemSecretValue\x12\x10\n\x06opaque\x18\x02 \x01(\tH\x00\x12\x35\n\x12\x64ocker_config_json\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12>\n\x0bopaque_pair\x18\x04 \x01(\x0b\x32\'.qwak.admiral.secret.v0.OpaquePairValueH\x00\x42\x07\n\x05value\"\x82\x01\n\x0fOpaquePairValue\x12\x41\n\x05pairs\x18\x04 \x03(\x0b\x32\x32.qwak.admiral.secret.v0.OpaquePairValue.PairsEntry\x1a,\n\nPairsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n\x0e\x41\x63\x63ountSecrets\x12\x42\n\x07secrets\x18\x01 \x03(\x0b\x32\x31.qwak.admiral.secret.v0.EnvironmentSecretMetadata\"\xc9\x01\n\x19\x45nvironmentSecretMetadata\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0flast_updated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')



_USERSECRETSPEC = DESCRIPTOR.message_types_by_name['UserSecretSpec']
_SYSTEMSECRETSPEC = DESCRIPTOR.message_types_by_name['SystemSecretSpec']
_SYSTEMSECRETDEFINITION = DESCRIPTOR.message_types_by_name['SystemSecretDefinition']
_ENVIRONMENTSECRETIDENTIFIER = DESCRIPTOR.message_types_by_name['EnvironmentSecretIdentifier']
_SETUSERENVIRONMENTSECRETOPTIONS = DESCRIPTOR.message_types_by_name['SetUserEnvironmentSecretOptions']
_SETSYSTEMENVIRONMENTSECRETOPTIONS = DESCRIPTOR.message_types_by_name['SetSystemEnvironmentSecretOptions']
_SYSTEMSECRETVALUE = DESCRIPTOR.message_types_by_name['SystemSecretValue']
_OPAQUEPAIRVALUE = DESCRIPTOR.message_types_by_name['OpaquePairValue']
_OPAQUEPAIRVALUE_PAIRSENTRY = _OPAQUEPAIRVALUE.nested_types_by_name['PairsEntry']
_ACCOUNTSECRETS = DESCRIPTOR.message_types_by_name['AccountSecrets']
_ENVIRONMENTSECRETMETADATA = DESCRIPTOR.message_types_by_name['EnvironmentSecretMetadata']
UserSecretSpec = _reflection.GeneratedProtocolMessageType('UserSecretSpec', (_message.Message,), {
  'DESCRIPTOR' : _USERSECRETSPEC,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.UserSecretSpec)
  })
_sym_db.RegisterMessage(UserSecretSpec)

SystemSecretSpec = _reflection.GeneratedProtocolMessageType('SystemSecretSpec', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETSPEC,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretSpec)
  })
_sym_db.RegisterMessage(SystemSecretSpec)

SystemSecretDefinition = _reflection.GeneratedProtocolMessageType('SystemSecretDefinition', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETDEFINITION,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretDefinition)
  })
_sym_db.RegisterMessage(SystemSecretDefinition)

EnvironmentSecretIdentifier = _reflection.GeneratedProtocolMessageType('EnvironmentSecretIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTSECRETIDENTIFIER,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.EnvironmentSecretIdentifier)
  })
_sym_db.RegisterMessage(EnvironmentSecretIdentifier)

SetUserEnvironmentSecretOptions = _reflection.GeneratedProtocolMessageType('SetUserEnvironmentSecretOptions', (_message.Message,), {
  'DESCRIPTOR' : _SETUSERENVIRONMENTSECRETOPTIONS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetUserEnvironmentSecretOptions)
  })
_sym_db.RegisterMessage(SetUserEnvironmentSecretOptions)

SetSystemEnvironmentSecretOptions = _reflection.GeneratedProtocolMessageType('SetSystemEnvironmentSecretOptions', (_message.Message,), {
  'DESCRIPTOR' : _SETSYSTEMENVIRONMENTSECRETOPTIONS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetSystemEnvironmentSecretOptions)
  })
_sym_db.RegisterMessage(SetSystemEnvironmentSecretOptions)

SystemSecretValue = _reflection.GeneratedProtocolMessageType('SystemSecretValue', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETVALUE,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretValue)
  })
_sym_db.RegisterMessage(SystemSecretValue)

OpaquePairValue = _reflection.GeneratedProtocolMessageType('OpaquePairValue', (_message.Message,), {

  'PairsEntry' : _reflection.GeneratedProtocolMessageType('PairsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OPAQUEPAIRVALUE_PAIRSENTRY,
    '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
    # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.OpaquePairValue.PairsEntry)
    })
  ,
  'DESCRIPTOR' : _OPAQUEPAIRVALUE,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.OpaquePairValue)
  })
_sym_db.RegisterMessage(OpaquePairValue)
_sym_db.RegisterMessage(OpaquePairValue.PairsEntry)

AccountSecrets = _reflection.GeneratedProtocolMessageType('AccountSecrets', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSECRETS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.AccountSecrets)
  })
_sym_db.RegisterMessage(AccountSecrets)

EnvironmentSecretMetadata = _reflection.GeneratedProtocolMessageType('EnvironmentSecretMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTSECRETMETADATA,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.EnvironmentSecretMetadata)
  })
_sym_db.RegisterMessage(EnvironmentSecretMetadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _OPAQUEPAIRVALUE_PAIRSENTRY._options = None
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_options = b'8\001'
  _USERSECRETSPEC._serialized_start=126
  _USERSECRETSPEC._serialized_end=157
  _SYSTEMSECRETSPEC._serialized_start=159
  _SYSTEMSECRETSPEC._serialized_end=235
  _SYSTEMSECRETDEFINITION._serialized_start=238
  _SYSTEMSECRETDEFINITION._serialized_end=391
  _ENVIRONMENTSECRETIDENTIFIER._serialized_start=393
  _ENVIRONMENTSECRETIDENTIFIER._serialized_end=460
  _SETUSERENVIRONMENTSECRETOPTIONS._serialized_start=463
  _SETUSERENVIRONMENTSECRETOPTIONS._serialized_end=623
  _SETSYSTEMENVIRONMENTSECRETOPTIONS._serialized_start=626
  _SETSYSTEMENVIRONMENTSECRETOPTIONS._serialized_end=790
  _SYSTEMSECRETVALUE._serialized_start=793
  _SYSTEMSECRETVALUE._serialized_end=958
  _OPAQUEPAIRVALUE._serialized_start=961
  _OPAQUEPAIRVALUE._serialized_end=1091
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_start=1047
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_end=1091
  _ACCOUNTSECRETS._serialized_start=1093
  _ACCOUNTSECRETS._serialized_end=1177
  _ENVIRONMENTSECRETMETADATA._serialized_start=1180
  _ENVIRONMENTSECRETMETADATA._serialized_end=1381
# @@protoc_insertion_point(module_scope)
