"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetricThresholdDirection:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetricThresholdDirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetricThresholdDirection.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_METRIC_DIRECTION: _MetricThresholdDirection.ValueType  # 0
    BELOW: _MetricThresholdDirection.ValueType  # 1
    ABOVE: _MetricThresholdDirection.ValueType  # 2
    EQUALS: _MetricThresholdDirection.ValueType  # 3
    BELOW_OR_EQUALS: _MetricThresholdDirection.ValueType  # 4
    ABOVE_OR_EQUALS: _MetricThresholdDirection.ValueType  # 5

class MetricThresholdDirection(_MetricThresholdDirection, metaclass=_MetricThresholdDirectionEnumTypeWrapper): ...

INVALID_METRIC_DIRECTION: MetricThresholdDirection.ValueType  # 0
BELOW: MetricThresholdDirection.ValueType  # 1
ABOVE: MetricThresholdDirection.ValueType  # 2
EQUALS: MetricThresholdDirection.ValueType  # 3
BELOW_OR_EQUALS: MetricThresholdDirection.ValueType  # 4
ABOVE_OR_EQUALS: MetricThresholdDirection.ValueType  # 5
global___MetricThresholdDirection = MetricThresholdDirection

class Metric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_METRIC_FIELD_NUMBER: builtins.int
    @property
    def sql_metric(self) -> global___SqlMetric: ...
    def __init__(
        self,
        *,
        sql_metric: global___SqlMetric | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric", b"metric", "sql_metric", b"sql_metric"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric", b"metric", "sql_metric", b"sql_metric"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["metric", b"metric"]) -> typing_extensions.Literal["sql_metric"] | None: ...

global___Metric = Metric

class SqlMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_QUERY_FIELD_NUMBER: builtins.int
    sql_query: builtins.str
    def __init__(
        self,
        *,
        sql_query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sql_query", b"sql_query"]) -> None: ...

global___SqlMetric = SqlMetric
