# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.prompt.v1.prompt import prompt_manager_service_pb2 as qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2


class PromptManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/CreatePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.FromString,
                )
        self.CreatePromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/CreatePromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.FromString,
                )
        self.UpdatePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/UpdatePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.FromString,
                )
        self.GetPromptByName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptByName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.FromString,
                )
        self.ListPrompts = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPrompts',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.FromString,
                )
        self.GetPromptVersionByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptVersionByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.FromString,
                )
        self.InitPaginationByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/InitPaginationByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.FromString,
                )
        self.ListPromptVersionsByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptVersionsByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.FromString,
                )
        self.DeletePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/DeletePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.FromString,
                )
        self.DeletePromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/DeletePromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.FromString,
                )
        self.SetDefaultPromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/SetDefaultPromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.FromString,
                )
        self.ListPromptBriefs = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptBriefs',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.FromString,
                )


class PromptManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreatePrompt(self, request, context):
        """Create a new prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePromptVersion(self, request, context):
        """Create new prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePrompt(self, request, context):
        """Update Prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromptByName(self, request, context):
        """Get prompt with its default version by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPrompts(self, request, context):
        """List all prompts with their default version in the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromptVersionByPromptName(self, request, context):
        """Get prompt version by name and optional version number
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPaginationByPromptName(self, request, context):
        """Init pagination by prompt name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromptVersionsByPromptName(self, request, context):
        """List prompt versions by prompt name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePrompt(self, request, context):
        """Delete prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePromptVersion(self, request, context):
        """Delete prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultPromptVersion(self, request, context):
        """Set default prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromptBriefs(self, request, context):
        """List all prompts briefs in the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PromptManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.SerializeToString,
            ),
            'CreatePromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.SerializeToString,
            ),
            'UpdatePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.SerializeToString,
            ),
            'GetPromptByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromptByName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.SerializeToString,
            ),
            'ListPrompts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPrompts,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.SerializeToString,
            ),
            'GetPromptVersionByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromptVersionByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.SerializeToString,
            ),
            'InitPaginationByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPaginationByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.SerializeToString,
            ),
            'ListPromptVersionsByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromptVersionsByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.SerializeToString,
            ),
            'DeletePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.SerializeToString,
            ),
            'DeletePromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.SerializeToString,
            ),
            'SetDefaultPromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultPromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.SerializeToString,
            ),
            'ListPromptBriefs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromptBriefs,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.prompt.v1.prompt.PromptManagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PromptManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreatePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/CreatePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/CreatePromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/UpdatePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromptByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptByName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPrompts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPrompts',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromptVersionByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptVersionByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPaginationByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/InitPaginationByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromptVersionsByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptVersionsByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/DeletePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/DeletePromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultPromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/SetDefaultPromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromptBriefs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptBriefs',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
