"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TimeUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimeUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIME_UNIT_INVALID: _TimeUnit.ValueType  # 0
    TIME_UNIT_WEEKS: _TimeUnit.ValueType  # 3
    TIME_UNIT_DAYS: _TimeUnit.ValueType  # 4
    TIME_UNIT_HOURS: _TimeUnit.ValueType  # 5
    TIME_UNIT_MINUTES: _TimeUnit.ValueType  # 6
    TIME_UNIT_SECONDS: _TimeUnit.ValueType  # 7

class TimeUnit(_TimeUnit, metaclass=_TimeUnitEnumTypeWrapper): ...

TIME_UNIT_INVALID: TimeUnit.ValueType  # 0
TIME_UNIT_WEEKS: TimeUnit.ValueType  # 3
TIME_UNIT_DAYS: TimeUnit.ValueType  # 4
TIME_UNIT_HOURS: TimeUnit.ValueType  # 5
TIME_UNIT_MINUTES: TimeUnit.ValueType  # 6
TIME_UNIT_SECONDS: TimeUnit.ValueType  # 7
global___TimeUnit = TimeUnit

class AggregationField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_WINDOWS_FIELD_NUMBER: builtins.int
    FIELD_NAME_PREFIX_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    AVG_FIELD_NUMBER: builtins.int
    SAMPLE_VARIANCE_FIELD_NUMBER: builtins.int
    POPULATION_VARIANCE_FIELD_NUMBER: builtins.int
    SAMPLE_STDEV_FIELD_NUMBER: builtins.int
    POPULATION_STDEV_FIELD_NUMBER: builtins.int
    BOOLEAN_AND_FIELD_NUMBER: builtins.int
    BOOLEAN_OR_FIELD_NUMBER: builtins.int
    LAST_DISTINCT_N_FIELD_NUMBER: builtins.int
    LAST_N_FIELD_NUMBER: builtins.int
    PERCENTILE_FIELD_NUMBER: builtins.int
    @property
    def time_windows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeWindow]:
        """Aggregation window size in seconds"""
    field_name_prefix: builtins.str
    """Field name prefix"""
    @property
    def count(self) -> global___Count: ...
    @property
    def sum(self) -> global___Sum: ...
    @property
    def max(self) -> global___Max: ...
    @property
    def min(self) -> global___Min: ...
    @property
    def avg(self) -> global___Avg: ...
    @property
    def sample_variance(self) -> global___SampleVariance: ...
    @property
    def population_variance(self) -> global___PopulationVariance: ...
    @property
    def sample_stdev(self) -> global___SampleSTDEV: ...
    @property
    def population_stdev(self) -> global___PopulationSTDEV: ...
    @property
    def boolean_and(self) -> global___BooleanAnd: ...
    @property
    def boolean_or(self) -> global___BooleanOr: ...
    @property
    def last_distinct_n(self) -> global___LastDistinctN: ...
    @property
    def last_n(self) -> global___LastN: ...
    @property
    def percentile(self) -> global___Percentile: ...
    def __init__(
        self,
        *,
        time_windows: collections.abc.Iterable[global___TimeWindow] | None = ...,
        field_name_prefix: builtins.str = ...,
        count: global___Count | None = ...,
        sum: global___Sum | None = ...,
        max: global___Max | None = ...,
        min: global___Min | None = ...,
        avg: global___Avg | None = ...,
        sample_variance: global___SampleVariance | None = ...,
        population_variance: global___PopulationVariance | None = ...,
        sample_stdev: global___SampleSTDEV | None = ...,
        population_stdev: global___PopulationSTDEV | None = ...,
        boolean_and: global___BooleanAnd | None = ...,
        boolean_or: global___BooleanOr | None = ...,
        last_distinct_n: global___LastDistinctN | None = ...,
        last_n: global___LastN | None = ...,
        percentile: global___Percentile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aggregator", b"aggregator", "avg", b"avg", "boolean_and", b"boolean_and", "boolean_or", b"boolean_or", "count", b"count", "last_distinct_n", b"last_distinct_n", "last_n", b"last_n", "max", b"max", "min", b"min", "percentile", b"percentile", "population_stdev", b"population_stdev", "population_variance", b"population_variance", "sample_stdev", b"sample_stdev", "sample_variance", b"sample_variance", "sum", b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregator", b"aggregator", "avg", b"avg", "boolean_and", b"boolean_and", "boolean_or", b"boolean_or", "count", b"count", "field_name_prefix", b"field_name_prefix", "last_distinct_n", b"last_distinct_n", "last_n", b"last_n", "max", b"max", "min", b"min", "percentile", b"percentile", "population_stdev", b"population_stdev", "population_variance", b"population_variance", "sample_stdev", b"sample_stdev", "sample_variance", b"sample_variance", "sum", b"sum", "time_windows", b"time_windows"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["aggregator", b"aggregator"]) -> typing_extensions.Literal["count", "sum", "max", "min", "avg", "sample_variance", "population_variance", "sample_stdev", "population_stdev", "boolean_and", "boolean_or", "last_distinct_n", "last_n", "percentile"] | None: ...

global___AggregationField = AggregationField

class TimeWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_UNIT_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    time_unit: global___TimeUnit.ValueType
    """Timeframe - hours, days, minutes, hours, etc"""
    length: builtins.int
    """time window length"""
    def __init__(
        self,
        *,
        time_unit: global___TimeUnit.ValueType = ...,
        length: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["length", b"length", "time_unit", b"time_unit"]) -> None: ...

global___TimeWindow = TimeWindow

class Count(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Count = Count

class Sum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Sum = Sum

class Max(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Max = Max

class Min(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Min = Min

class Avg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Avg = Avg

class SampleVariance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___SampleVariance = SampleVariance

class PopulationVariance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___PopulationVariance = PopulationVariance

class SampleSTDEV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___SampleSTDEV = SampleSTDEV

class PopulationSTDEV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___PopulationSTDEV = PopulationSTDEV

class BooleanAnd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___BooleanAnd = BooleanAnd

class BooleanOr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___BooleanOr = BooleanOr

class LastDistinctN(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    n: builtins.int
    """value of N"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        n: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "n", b"n"]) -> None: ...

global___LastDistinctN = LastDistinctN

class LastN(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    n: builtins.int
    """value of N"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        n: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "n", b"n"]) -> None: ...

global___LastN = LastN

class Percentile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    p: builtins.int
    """rank value - an int between 1 and 99. 50 means median etc."""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        p: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "p", b"p"]) -> None: ...

global___Percentile = Percentile
